saddle-runtime 0.3.1

Saddle managed asynchronous runtime and lifecycle
docs.rs failed to build saddle-runtime-0.3.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: saddle-runtime-0.3.8

Saddle-managed async runtime and application lifecycle.

V1 intentionally exposes no general-purpose spawn or runtime-construction API to business code.