Crate saddle_runtime

Crate saddle_runtime 

Saddle-managed async runtime and application lifecycle.

V1 intentionally exposes no general-purpose spawn or runtime-construction API to business code.

Structs

Application
A complete Saddle application hosted by the process-wide async runtime.
RequestGuard
Proof that one request was admitted by Saddle before shutdown began.
RequestLifecycle
Coordinates request admission with graceful application shutdown.

Enums

ApplicationPhase
The externally visible phase of the Saddle application lifecycle.

Traits

ComponentLifecycle
Object-safe lifecycle contract used by the Saddle application assembler.

Type Aliases

LifecycleFuture